@@ -151,21 +151,21 @@ def make_upload_header(token, org_id):
 	return {
 		'Authorization': f'Zoho-oauthtoken {token.access}',
 		'feature': 'bulk-write',
-		'X-CRM-ORG': org_id,
-		'Content-Type': "multipart/form-data"
+		'X-CRM-ORG': org_id
 
 	}
 		#'Content-Type': "multipart/form-data"
 	#}
 
 def upload_csv(token, org_id, module, filename):
-	url = "https://content.zohoapis.com/crm/v3/upload"
+	url = "https://content.zohoapis.com/crm/v2.1/upload"
 	headers = make_upload_header(token, org_id)
 	with open(filename, 'rb') as upload_file:
-		#files = {'file': upload_file}
-		files = ('file', upload_file)
-		request_body = [files]
-		
+		request_body = {'file': upload_file}
+		#files = ('file', upload_file)
+		#request_body = [files]
+		#payload = {}
+
 		response = requests.post(url=url, headers=headers, data=request_body)
 	#files = {"file": open(filename, 'rb')}
 
